test

# configurator report¶

This notebook contains the automatic `configurator` report based on preliminary PE results.

Data provenance

PE summary file | /Users/hestelles/Downloads/IGWN-GWTC2p1-v2-GW190814_211039_PEDataRelease_mixed_cosmo.h5
Data set | C01:IMRPhenomXPHM
md5sum of file | 0231d2a2338fd8f042887280a2ad4a6a
git revision of data | N/A__DIRTY

Settings

$f_{\rm low}$ | 20.0 Hz
$f_{\rm ref}$ | 20.0 Hz
Max $\ell$ for Nyquist check | 3
Tolerance for railing | 2.0
nbins for railing | 50

## Automatically generated analysis¶

- Mass 2 has strong support for mass < 3 $M_{\odot}$

- **Equal masses are excluded at high confidence for this event!

Median mass ratio is below 1/3, highly unequal mass event!**

- The median network matched filter SNR is above 25.0! Very loud event?

- $a_{1}$ is well constrained!\n

## Summary of posterior sample parameters¶

| $\mathcal{M}$ | $M_{\rm total}$ | $q$ | $d_{L}$ | $\chi_{1z}$ | $\chi_{2z}$
--- | --- | --- | --- | --- | --- | ---
count | 78254.000000 | 78254.000000 | 78254.000000 | 78254.000000 | 78254.000000 | 78254.000000
mean | 6.417358 | 27.220260 | 0.111642 | 231.999798 | -0.002345 | 0.053209
std | 0.011898 | 0.994969 | 0.009366 | 27.404693 | 0.050648 | 0.307782
min | 6.250720 | 17.768954 | 0.060567 | 101.424606 | -0.776414 | -0.976369
25% | 6.411350 | 26.798937 | 0.107561 | 214.213196 | -0.012452 | -0.114745
50% | 6.417275 | 27.205884 | 0.111191 | 232.695594 | 0.000007 | 0.024746
75% | 6.423768 | 27.665779 | 0.114621 | 250.564949 | 0.013290 | 0.228742
max | 6.527174 | 37.582966 | 0.300137 | 334.812163 | 0.330088 | 0.981098

## Posterior railing visual check¶

Automatic checks on railing. Note that the recommendations are ad-hoc and may not result in posteriors not being cut off.

|  | Recommendation
--- | --- | ---
chirp_mass | PASSED |
distance | PASSED |
mass_ratio | PASSED |

Plot of selected posterior parameters. All masses are in the detector frame. The red dashed lines show the proposed $\mathcal{M}$ bounds,[6.1954,6.5825]

## MECO frequency check¶

The reference frequency is shown as a dashed green vertical line. If the reference frequency has been modified by the MECO test, the input value appears in red and the new value in green.

|  | Recommendation
--- | --- | ---
f_ref | PASSED |

## Recommended settings¶

seglen | 16.0 sec.
srate | 4096
$f_{\rm start}$ | 13.3333 Hz
$f_{\rm ref}$ | 20.0 Hz
$\mathcal{M}$ bounds | [6.1954,6.5825]

## Extra information¶

Date | 2023-04-12 09:51:58.908654
Script revision | ad853bac7cca41f13b704b059414ff09d8157603__DIRTY
Complete arguments | Namespace(output_dir='examples/test_GW190814', HM=True, q_min=None, ell_max=3, tolerance=2.0, nbins=50, flow=20.0, f_ref=20.0, bounds_tol=0.2, json_file='test.json', report_file='test.pdf', override_safeties=False, debug=False, include_dL_recommendations=False)